@@ -114,20 +114,19 @@ static AB_BANKINFO_PLUGIN *AB_Banking__GetBankInfoPlugin(AB_BANKING *ab,
 
 static int AB_Banking__ReadImExporterProfiles(AB_BANKING *ab,
                                               const char *path,
-                                              GWEN_DB_NODE *db);
+					      GWEN_DB_NODE *db,
+					      int isGlobal);
 
 
-static int AB_Banking_InitProvider(AB_BANKING *ab, AB_PROVIDER *pro, uint32_t guiid);
-static int AB_Banking_FiniProvider(AB_BANKING *ab, AB_PROVIDER *pro, uint32_t guiid);
+static int AB_Banking_InitProvider(AB_BANKING *ab, AB_PROVIDER *pro);
+static int AB_Banking_FiniProvider(AB_BANKING *ab, AB_PROVIDER *pro);
 
 static int AB_Banking__ExecuteQueue(AB_BANKING *ab, AB_JOB_LIST2 *jl2,
-                                    AB_IMEXPORTER_CONTEXT *ctx,
-                                    uint32_t pid);
+                                    AB_IMEXPORTER_CONTEXT *ctx);
 
 
 static AB_ACCOUNT *AB_Banking__GetAccount(AB_BANKING *ab,
-					  const char *accountId,
-					  uint32_t guiid);
+					  const char *accountId);
 
 static int AB_Banking__GetDebuggerPath(AB_BANKING *ab,
                                        const char *backend,
@@ -139,26 +138,33 @@ static int AB_Banking__TransformIban(const char *iban, int len,
 
 static uint64_t AB_Banking__char2uint64(const char *accountId);
 
-static void AB_Banking_ActivateAllProviders(AB_BANKING *ab, uint32_t guiid);
+static void AB_Banking_ActivateAllProviders(AB_BANKING *ab);
 
 static void AB_Banking__fillTransactionFromAccount(AB_TRANSACTION *t, const AB_ACCOUNT *a);
 static void AB_Banking__fillTransactionRemoteInfo(AB_TRANSACTION *t);
 
 
-static int AB_Banking_LoadAllUsers(AB_BANKING *ab, uint32_t guiid);
+static int AB_Banking_LoadAllUsers(AB_BANKING *ab);
 
-static int AB_Banking_LoadAllAccounts(AB_BANKING *ab, uint32_t guiid);
+static int AB_Banking_LoadAllAccounts(AB_BANKING *ab);
 
-static int AB_Banking_LoadConfig(AB_BANKING *ab, uint32_t guiid);
-static int AB_Banking_UnloadConfig(AB_BANKING *ab, uint32_t guiid);
-static int AB_Banking_SaveConfig(AB_BANKING *ab, uint32_t guiid);
+static int AB_Banking_LoadConfig(AB_BANKING *ab);
+static int AB_Banking_UnloadConfig(AB_BANKING *ab);
+static int AB_Banking_SaveConfig(AB_BANKING *ab);
 
 /* only for import of older configurations */
-static int AB_Banking_SetUniqueId(AB_BANKING *ab, uint32_t uid, uint32_t guiid);
+static int AB_Banking_SetUniqueId(AB_BANKING *ab, uint32_t uid);
 
 static int AB_Banking__ImportConfDir(AB_BANKING *ab,
 				     const char *path,
-				     const char *groupName,
-				     uint32_t guiid);
+				     const char *groupName);
+
+/**
+ * Write the settings of the user while in exclusive use. This is also called
+ * internally by @ref AB_Banking_EndExclUseUser.
+ * Please note that the user must be locked with @ref AB_Banking_BeginExclUseUser.
+ */
+static int AB_Banking_SaveUser(AB_BANKING *ab, AB_USER *u);
+
 
 #endif /* AQBANKING_BANKING_P_H */
