@@ -59,7 +59,7 @@ int AB_JobSingleTransfer_SetTransaction(AB_JOB *j, const AB_TRANSACTION *t);
  * transaction.
  */
 AQBANKING_API 
-const AB_TRANSACTION *AB_JobSingleTransfer_GetTransaction(const AB_JOB *j);
+AB_TRANSACTION *AB_JobSingleTransfer_GetTransaction(const AB_JOB *j);
 /*@}*/
 
 
