@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: jobtransferbase_p.h 764 2006-01-13 14:00:00Z cstim $
+ cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -25,7 +26,7 @@ struct AB_JOBTRANSFERBASE {
   AB_TRANSACTION_LIMITS *limits;
   int *textKeys;
 };
-static void AB_JobTransferBase_FreeData(void *bp, void *p);
+static void GWENHYWFAR_CB AB_JobTransferBase_FreeData(void *bp, void *p);
 
 
 #endif
