@@ -1,13 +1,14 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: balance.h 1009 2006-05-11 19:59:20Z martin $
+    cvs         : $Id$
     begin       : Mon Apr 05 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
- *          Please see toplevel file COPYING for license details           *
+ * This file is part of the project "AqBanking".                           *
+ * Please see toplevel file COPYING of that project for license details.   *
  ***************************************************************************/
 
 
@@ -38,6 +39,8 @@ void AB_Balance_free(AB_BALANCE *b);
 AQBANKING_API 
 const AB_VALUE *AB_Balance_GetValue(const AB_BALANCE *b);
 AQBANKING_API 
+void AB_Balance_SetValue(AB_BALANCE *b, const AB_VALUE *v);
+AQBANKING_API 
 const GWEN_TIME *AB_Balance_GetTime(const AB_BALANCE *b);
 
 #ifdef __cplusplus
