@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2011 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -40,6 +37,10 @@
 
 /*#define CHALLENGE_ADD_ONLY_PREKOMMA_VALUES*/
 
+#define AH_MULTI_CHALLENGE_CLASS_HKSUB 12
+#define AH_MULTI_CHALLENGE_CLASS_HKSLA 19
+
+
 
 
 GWEN_INHERIT(AH_JOB, AH_JOB_MULTITRANSFER);
@@ -53,7 +54,7 @@ AH_JOB *AH_Job_MultiTransfer_new(AB_USER *u,
 
   j=AH_Job_MultiTransferBase_new(u, account, 1);
   if (j)
-    AH_Job_SetChallengeClass(j, 50);
+    AH_Job_SetChallengeClass(j, AH_MULTI_CHALLENGE_CLASS_HKSUB);
   return j;
 }
 
@@ -66,7 +67,7 @@ AH_JOB *AH_Job_MultiDebitNote_new(AB_USER *u,
 
   j=AH_Job_MultiTransferBase_new(u, account, 0);
   if (j)
-    AH_Job_SetChallengeClass(j, 50);
+    AH_Job_SetChallengeClass(j, AH_MULTI_CHALLENGE_CLASS_HKSLA);
   return j;
 }
 
@@ -94,12 +95,14 @@ AH_JOB *AH_Job_MultiTransferBase_new(AB_USER *u,
                        AH_Job_MultiTransfer_FreeData);
   aj->isTransfer=isTransfer;
   aj->sumRemoteAccountId=AB_Value_new();
+  aj->sumRemoteBankCode=AB_Value_new();
   aj->sumValues=AB_Value_new();
 
   /* overwrite some virtual functions */
   AH_Job_SetProcessFn(j, AH_Job_MultiTransfer_Process);
   AH_Job_SetExchangeFn(j, AH_Job_MultiTransfer_Exchange);
   AH_Job_SetPrepareFn(j, AH_Job_MultiTransfer_Prepare);
+  AH_Job_SetAddChallengeParamsFn(j, AH_Job_MultiTransfer_AddChallengeParams);
 
   /* set some known arguments */
   dbArgs=AH_Job_GetArguments(j);
@@ -149,6 +152,7 @@ void GWENHYWFAR_CB AH_Job_MultiTransfer_FreeData(void *bp, void *p){
   aj=(AH_JOB_MULTITRANSFER*)p;
 
   AB_Value_free(aj->sumValues);
+  AB_Value_free(aj->sumRemoteBankCode);
   AB_Value_free(aj->sumRemoteAccountId);
 
   GWEN_FREE_OBJECT(aj);
@@ -531,6 +535,7 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 	char tbuf[11];
         AB_VALUE *tv;
 
+        /* sum up account ids */
 	s=AB_Transaction_GetRemoteAccountNumber(t);
 	assert(s);
         tbuf[0]=0;
@@ -540,6 +545,16 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 	AB_Value_AddValue(aj->sumRemoteAccountId, tv);
 	AB_Value_free(tv);
 
+        /* sum up bank codes */
+        s=AB_Transaction_GetRemoteBankCode(t);
+	assert(s);
+        tbuf[0]=0;
+	strncat(tbuf, s, 10);
+	tv=AB_Value_fromString(tbuf);
+	assert(tv);
+	AB_Value_AddValue(aj->sumRemoteBankCode, tv);
+	AB_Value_free(tv);
+
 #ifdef CHALLENGE_ADD_ONLY_PREKOMMA_VALUES
 	if (1) {
 	  GWEN_BUFFER *tbuf;
@@ -664,31 +679,141 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 
 
 int AH_Job_MultiTransfer_Prepare(AH_JOB *j){
+#if 0
+  /* this code should no longer be needed since we use
+   * AH_Job_MultiTransfer_AddChallengeParams now */
+
   AH_JOB_MULTITRANSFER *aj;
   GWEN_BUFFER *tbuf;
   char *p;
 
-  DBG_DEBUG(AQHBCI_LOGDOMAIN, "Prepare function called");
+  DBG_ERROR(AQHBCI_LOGDOMAIN, "Prepare function called");
 
   assert(j);
   aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_MULTITRANSFER, j);
   assert(aj);
 
-  AH_Job_SetChallengeClass(j, 50);
-
   tbuf=GWEN_Buffer_new(0, 32, 0, 1);
 
   /* set challenge parameter */
+
+  /* add sum of account numbers */
   AB_Value_toHumanReadableString2(aj->sumRemoteAccountId,
 				  tbuf, 0, 0);
   p=strchr(GWEN_Buffer_GetStart(tbuf), '.');
   if (p)
     *p=0;
   AH_Job_AddChallengeParam(j, GWEN_Buffer_GetStart(tbuf));
+  GWEN_Buffer_Reset(tbuf);
+
+  /* add sum of bank codes */
+  AB_Value_toHumanReadableString2(aj->sumRemoteBankCode,
+                                  tbuf, 0, 0);
+  p=strchr(GWEN_Buffer_GetStart(tbuf), '.');
+  if (p)
+    *p=0;
+  AH_Job_AddChallengeParam(j, GWEN_Buffer_GetStart(tbuf));
+
+
   GWEN_Buffer_free(tbuf);
 
+  if (aj->sumValues) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "Setting value");
+  }
   AH_Job_SetChallengeValue(j, aj->sumValues);
 
+#endif
+
+  return 0;
+}
+
+
+int AH_Job_MultiTransfer_AddChallengeParams(AH_JOB *j, int hkTanVer, GWEN_DB_NODE *dbMethod) {
+  AH_JOB_MULTITRANSFER *aj;
+  const char *s;
+  int tanVer=AH_JOB_TANVER_1_4;
+  char *p;
+  AB_ACCOUNT *acc=NULL;
+
+  DBG_ERROR(AQHBCI_LOGDOMAIN, "AddChallengeParams function called");
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_MULTITRANSFER, j);
+  assert(aj);
+
+  s=GWEN_DB_GetCharValue(dbMethod, "zkaTanVersion", 0, NULL);
+  if (s && *s && strncasecmp(s, "1.3", 3)==0) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "TAN version is 1.3 (%s)", s);
+    tanVer=AH_JOB_TANVER_1_3;
+  }
+
+  /* set challenge parameter */
+  if (tanVer==AH_JOB_TANVER_1_4) {
+    GWEN_BUFFER *tbuf;
+    char numbuf[16];
+
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "TAN version is 1.4.x");
+    tbuf=GWEN_Buffer_new(0, 32, 0, 1);
+
+    if (aj->isTransfer)
+      AH_Job_SetChallengeClass(j, 12);
+    else
+      AH_Job_SetChallengeClass(j, 19);
+
+    /* P1: number of transfers */
+    snprintf(numbuf, sizeof(numbuf)-1, "%d", aj->transferCount);
+    numbuf[sizeof(numbuf)-1]=0;
+    AH_Job_AddChallengeParam(j, numbuf);
+
+    /* P2: sum of amount */
+    AH_Job_ValueToChallengeString(aj->sumValues, tbuf);
+    AH_Job_AddChallengeParam(j, GWEN_Buffer_GetStart(tbuf));
+    GWEN_Buffer_Reset(tbuf);
+
+    /* P3: local account number */
+    acc=AH_AccountJob_GetAccount(j);
+    assert(acc);
+    s=AB_Account_GetAccountNumber(acc);
+    if (s && *s) {
+      int i;
+
+      GWEN_Buffer_AppendString(tbuf, s);
+      i=10-strlen(s);
+      if (i>0) {
+        /* need to left-fill the account number with leading zeroes
+         * to a length of exactly 10 digits */
+        GWEN_Buffer_Rewind(tbuf);
+        GWEN_Buffer_FillLeftWithBytes(tbuf, '0', i);
+      }
+      AH_Job_AddChallengeParam(j, GWEN_Buffer_GetStart(tbuf));
+      GWEN_Buffer_Reset(tbuf);
+    }
+    else {
+      DBG_ERROR(AQHBCI_LOGDOMAIN, "No account number");
+      GWEN_Buffer_free(tbuf);
+      return GWEN_ERROR_INVALID;
+    }
+
+    /* add sum of account numbers */
+    AB_Value_toHumanReadableString2(aj->sumRemoteAccountId,
+                                    tbuf, 0, 0);
+    p=strchr(GWEN_Buffer_GetStart(tbuf), '.');
+    if (p)
+      *p=0;
+    /* only use first 10 digits */
+    GWEN_Buffer_Crop(tbuf, 0, 10);
+    AH_Job_AddChallengeParam(j, GWEN_Buffer_GetStart(tbuf));
+    GWEN_Buffer_Reset(tbuf);
+
+
+    /* done */
+    GWEN_Buffer_free(tbuf);
+  }
+  else {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "Unhandled tan version %d for now", tanVer);
+    return GWEN_ERROR_INTERNAL;
+  }
+
   return 0;
 }
 
