@@ -26,6 +26,7 @@
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/gui.h>
 #include <gwenhywfar/inherit.h>
+#include <gwenhywfar/text.h>
 
 #include <stdlib.h>
 #include <assert.h>
@@ -100,10 +101,10 @@ AH_JOB *AH_Job_GetKeys_new(AB_USER *u){
 
 /* --------------------------------------------------------------- FUNCTION */
 void GWENHYWFAR_CB GWENHYWFAR_CB AH_Job_GetKeys_FreeData(void *bp, void *p){
-  AH_JOB *j;
+//  AH_JOB *j;
   AH_JOB_GETKEYS *jd;
 
-  j=(AH_JOB*) bp;
+//  j=(AH_JOB*) bp;
   jd=(AH_JOB_GETKEYS*) p;
 
   GWEN_Crypt_Token_KeyInfo_free(jd->signKeyInfo);
@@ -1299,7 +1300,7 @@ int AH_Job_Tan_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
 	  GWEN_BUFFER *bbuf;
 
 	  bbuf=GWEN_Buffer_new(0, 256, 0, 1);
-	  GWEN_Text_ToHexBuffer((const char*) p, l, 0, 0, 0);
+          GWEN_Text_ToHexBuffer((const char*) p, l, bbuf, 0, 0, 0);
 	  free(aj->challengeHhd);
 	  aj->challengeHhd=strdup(GWEN_Buffer_GetStart(bbuf));
 	  GWEN_Buffer_free(bbuf);
@@ -1455,8 +1456,14 @@ void AH_Job_Tan_SetSegCode(AH_JOB *j, const char *p) {
   dbArgs=AH_Job_GetArguments(j);
   assert(dbArgs);
 
-  GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
-                       "segmentId", p);
+  if (p && *p) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "Setting segment id in TAN to [%s]", p);
+    GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+			 "segmentId", p);
+  }
+  else {
+    GWEN_DB_DeleteVar(dbArgs, "segmentId");
+  }
 }
 
 
@@ -1571,12 +1578,12 @@ void AH_Job_Tan_SetSmsAccountInfo(AH_JOB *j,
 
 
 
-int AH_Job_Tan_FinishSetup(AH_JOB *j) {
+int AH_Job_Tan_FinishSetup(AH_JOB *j, AH_JOB *accJob) {
   AH_JOB_TAN *aj;
+  int rv;
   GWEN_DB_NODE *args;
   GWEN_DB_NODE *dbParams;
   GWEN_DB_NODE *dbMethod;
-  GWEN_STRINGLIST *sl;
   const char *s;
 
   assert(j);
@@ -1606,59 +1613,40 @@ int AH_Job_Tan_FinishSetup(AH_JOB *j) {
     return GWEN_ERROR_GENERIC;
   }
   
+  rv=AH_Job_AddChallengeParams(accJob, AH_Job_GetSegmentVersion(j), dbMethod);
+  if (rv<0) {
+    if (rv==GWEN_ERROR_NOT_SUPPORTED) {
+      DBG_INFO(AQHBCI_LOGDOMAIN, "Challenge parameters not supported by job, ignoring");
+    }
+    else {
+      DBG_ERROR(AQHBCI_LOGDOMAIN, "here (%d)", rv);
+      return rv;
+    }
+  }
+  else {
+    GWEN_STRINGLIST *sl;
+
+    /* add challenge params as provided by addChallengeParams function */
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "Using result of AddChallengeParams function");
+    sl=AH_Job_GetChallengeParams(accJob);
+    if (sl) {
+      GWEN_STRINGLISTENTRY *e;
+
+      e=GWEN_StringList_FirstEntry(sl);
+      while(e) {
+        GWEN_DB_SetCharValue(args, GWEN_DB_FLAGS_DEFAULT,
+                             "challengeParams/param",
+                             GWEN_StringListEntry_Data(e));
+        e=GWEN_StringListEntry_Next(e);
+      }
+    }
+  }
+
   /* set challenge class */
   s=GWEN_DB_GetCharValue(dbMethod, "needChallengeClass", 0, "N");
   if (strcasecmp(s, "J")==0)
     GWEN_DB_SetIntValue(args, GWEN_DB_FLAGS_OVERWRITE_VARS,
-			"challengeClass", AH_Job_GetChallengeClass(j));
-  
-  /* add challenge params */
-  sl=AH_Job_GetChallengeParams(j);
-  if (sl) {
-    GWEN_STRINGLISTENTRY *e;
-  
-    e=GWEN_StringList_FirstEntry(sl);
-    while(e) {
-      GWEN_DB_SetCharValue(args, GWEN_DB_FLAGS_DEFAULT,
-			   "challengeParams/param",
-			   GWEN_StringListEntry_Data(e));
-      e=GWEN_StringListEntry_Next(e);
-    }
-  }
-  
-  /* set challenge value if required */
-  s=GWEN_DB_GetCharValue(dbMethod, "needChallengeAmount", 0, "N");
-  if (strcasecmp(s, "J")==0) {
-    const AB_VALUE *v;
-
-    v=AH_Job_GetChallengeValue(j);
-    if (!v) {
-      DBG_INFO(AQHBCI_LOGDOMAIN,
-	       "Missing challenge amount value, ignoring");
-      /*return GWEN_ERROR_GENERIC; */
-    }
-    else {
-      GWEN_BUFFER *btmp;
-  
-      btmp=GWEN_Buffer_new(0, 32, 0, 1);
-      AH_Job_ValueToChallengeString(v, btmp);
-      DBG_ERROR(0, "Setting challenge amount [%s]", GWEN_Buffer_GetStart(btmp));
-      GWEN_DB_SetCharValue(args, GWEN_DB_FLAGS_DEFAULT,
-			   "challengeParams/param",
-			   GWEN_Buffer_GetStart(btmp));
-      GWEN_Buffer_free(btmp);
-      s=AB_Value_GetCurrency(v);
-      if (!s)
-	s="EUR";
-      if (s)
-	GWEN_DB_SetCharValue(args, GWEN_DB_FLAGS_DEFAULT,
-			     "challengeParams/param",
-			     s);
-    }
-  }
-  else {
-    DBG_INFO(AQHBCI_LOGDOMAIN, "Challenge amount not needed");
-  }
+                        "challengeClass", AH_Job_GetChallengeClass(accJob));
 
   return 0;
 }
