@@ -409,7 +409,7 @@ int AH_Msg_EncryptRdh3(AH_MSG *hmsg) {
   GWEN_MSGENGINE *e;
   AB_USER *u;
   const char *peerId;
-  uint32_t uFlags;
+//  uint32_t uFlags;
   GWEN_CRYPT_TOKEN *ct;
   const GWEN_CRYPT_TOKEN_CONTEXT *ctx;
   const GWEN_CRYPT_TOKEN_KEYINFO *ki;
@@ -429,7 +429,7 @@ int AH_Msg_EncryptRdh3(AH_MSG *hmsg) {
   gid=0;
 
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
-  uFlags=AH_User_GetFlags(u);
+//  uFlags=AH_User_GetFlags(u);
 
   peerId=AH_User_GetPeerId(u);
   if (!peerId || *peerId==0)
@@ -665,7 +665,7 @@ int AH_Msg_DecryptRdh3(AH_MSG *hmsg, GWEN_DB_NODE *gr){
   GWEN_MSGENGINE *e;
   AB_USER *u;
   const char *peerId;
-  uint32_t uFlags;
+//  uint32_t uFlags;
   GWEN_CRYPT_TOKEN *ct;
   const GWEN_CRYPT_TOKEN_CONTEXT *ctx;
   const GWEN_CRYPT_TOKEN_KEYINFO *ki;
@@ -687,7 +687,7 @@ int AH_Msg_DecryptRdh3(AH_MSG *hmsg, GWEN_DB_NODE *gr){
   gid=0;
 
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
-  uFlags=AH_User_GetFlags(u);
+//  uFlags=AH_User_GetFlags(u);
 
   peerId=AH_User_GetPeerId(u);
   if (!peerId || *peerId==0)
