@@ -411,7 +411,7 @@ int AH_Msg_EncryptRdh5(AH_MSG *hmsg) {
   GWEN_MSGENGINE *e;
   AB_USER *u;
   const char *peerId;
-  uint32_t uFlags;
+//  uint32_t uFlags;
   GWEN_CRYPT_TOKEN *ct;
   const GWEN_CRYPT_TOKEN_CONTEXT *ctx;
   const GWEN_CRYPT_TOKEN_KEYINFO *ki;
@@ -431,7 +431,7 @@ int AH_Msg_EncryptRdh5(AH_MSG *hmsg) {
   gid=0;
 
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
-  uFlags=AH_User_GetFlags(u);
+//  uFlags=AH_User_GetFlags(u);
 
   peerId=AH_User_GetPeerId(u);
   if (!peerId || *peerId==0)
@@ -675,7 +675,7 @@ int AH_Msg_DecryptRdh5(AH_MSG *hmsg, GWEN_DB_NODE *gr){
   GWEN_MSGENGINE *e;
   AB_USER *u;
   const char *peerId;
-  uint32_t uFlags;
+//  uint32_t uFlags;
   GWEN_CRYPT_TOKEN *ct;
   const GWEN_CRYPT_TOKEN_CONTEXT *ctx;
   const GWEN_CRYPT_TOKEN_KEYINFO *ki;
@@ -697,7 +697,7 @@ int AH_Msg_DecryptRdh5(AH_MSG *hmsg, GWEN_DB_NODE *gr){
   gid=0;
 
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
-  uFlags=AH_User_GetFlags(u);
+//  uFlags=AH_User_GetFlags(u);
 
   peerId=AH_User_GetPeerId(u);
   if (!peerId || *peerId==0)
