@@ -89,6 +89,9 @@ void AH_User_Flags_toDb(GWEN_DB_NODE *db, const char *name,
   if (flags & AH_USER_FLAGS_KEEP_MULTIPLE_BLANKS)
     GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_DEFAULT, name,
 			 "keepMultipleBlanks");
+  if (flags & AH_USER_FLAGS_TAN_OMIT_SMS_ACCOUNT)
+    GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_DEFAULT, name,
+                         "omitSmsAccount");
 }
 
 
@@ -118,6 +121,8 @@ uint32_t AH_User_Flags_fromDb(GWEN_DB_NODE *db, const char *name) {
       fl|=AH_USER_FLAGS_NO_BASE64;
     else if (strcasecmp(s, "keepMultipleBlanks")==0)
       fl|=AH_USER_FLAGS_KEEP_MULTIPLE_BLANKS;
+    else if (strcasecmp(s, "omitSmsAccount")==0)
+      fl|=AH_USER_FLAGS_TAN_OMIT_SMS_ACCOUNT;
     else {
       DBG_WARN(AQHBCI_LOGDOMAIN, "Unknown user flag \"%s\"", s);
     }
@@ -1813,6 +1818,43 @@ void AH_User_SetMaxDebitNotesPerJob(AB_USER *u, int i){
 
 
 
+int AH_User_AddTextWithoutTags(const char *s, GWEN_BUFFER *obuf) {
+  while(*s) {
+    if (*s=='<') {
+      const char *s2;
+      int l;
+
+      s2=s;
+      s2++;
+      while(*s2 && *s2!='>')
+	s2++;
+      l=s2-s-2;
+      if (l>0) {
+	const char *s3;
+
+	s3=s;
+	s3++;
+	if (l==2) {
+	  if (strncasecmp(s3, "br", 2)==0)
+	    GWEN_Buffer_AppendString(obuf, "\n");
+	}
+	else if (l==3) {
+	  if (strncasecmp(s3, "br/", 3)==0)
+	    GWEN_Buffer_AppendString(obuf, "\n");
+	}
+      }
+      s=s2; /* set s to position of closing bracket */
+    }
+    else
+      GWEN_Buffer_AppendByte(obuf, *s);
+    /* next char */
+    s++;
+  }
+
+  return 0;
+}
+
+
 
 int AH_User_InputTanWithChallenge2(AB_USER *u,
 				   const char *challenge,
@@ -1903,8 +1945,8 @@ int AH_User_InputTanWithChallenge2(AB_USER *u,
       if (s) {
 	/* skip "CHLGTEXT" and 4 digits */
 	s+=12;
-	/* add rest of the message */
-	GWEN_Buffer_AppendString(xbuf, s);
+	/* add rest of the message (replace HTML tags, if any) */
+	AH_User_AddTextWithoutTags(s, xbuf);
       }
       else {
 	/* create own text */
