@@ -196,13 +196,13 @@ void AIO_OfxGroup_STATUS_FreeData(void *bp, void *p) {
 int AIO_OfxGroup_STATUS_StartTag(AIO_OFX_GROUP *g,
 				 const char *tagName) {
   AIO_OFX_GROUP_STATUS *xg;
-  GWEN_XML_CONTEXT *ctx;
+  //GWEN_XML_CONTEXT *ctx;
 
   assert(g);
   xg=GWEN_INHERIT_GETDATA(AIO_OFX_GROUP, AIO_OFX_GROUP_STATUS, g);
   assert(xg);
 
-  ctx=AIO_OfxGroup_GetXmlContext(g);
+  //ctx=AIO_OfxGroup_GetXmlContext(g);
 
   free(xg->currentElement);
   xg->currentElement=NULL;
@@ -228,13 +228,13 @@ int AIO_OfxGroup_STATUS_StartTag(AIO_OFX_GROUP *g,
 
 int AIO_OfxGroup_STATUS_EndTag(AIO_OFX_GROUP *g, const char *tagName) {
   AIO_OFX_GROUP_STATUS *xg;
-  GWEN_XML_CONTEXT *ctx;
+  //GWEN_XML_CONTEXT *ctx;
 
   assert(g);
   xg=GWEN_INHERIT_GETDATA(AIO_OFX_GROUP, AIO_OFX_GROUP_STATUS, g);
   assert(xg);
 
-  ctx=AIO_OfxGroup_GetXmlContext(g);
+  //ctx=AIO_OfxGroup_GetXmlContext(g);
 
   assert(tagName);
   if (strcasecmp(tagName, AIO_OfxGroup_GetGroupName(g))!=0) {
