@@ -22,9 +22,9 @@ struct AH_IMEXPORTER_SEPA {
 
 
 AQBANKING_EXPORT
-GWEN_PLUGIN *imexporters_sepa_factory(GWEN_PLUGIN_MANAGER *pm,
-				      const char *name,
-				      const char *fileName);
+GWEN_PLUGIN *imexporter_sepa_factory(GWEN_PLUGIN_MANAGER *pm,
+				     const char *name,
+				     const char *fileName);
 
 static
 AB_IMEXPORTER *AB_Plugin_ImExporterSEPA_Factory(GWEN_PLUGIN *pl,
@@ -38,27 +38,24 @@ void GWENHYWFAR_CB AH_ImExporterSEPA_FreeData(void *bp, void *p);
 static
 int AH_ImExporterSEPA_Import(AB_IMEXPORTER *ie,
 			     AB_IMEXPORTER_CONTEXT *ctx,
-			     GWEN_IO_LAYER *io,
-			     GWEN_DB_NODE *params,
-			     uint32_t guiid);
+			     GWEN_SYNCIO *sio,
+			     GWEN_DB_NODE *params);
 
 static
 int AH_ImExporterSEPA_Export(AB_IMEXPORTER *ie,
 			     AB_IMEXPORTER_CONTEXT *ctx,
-			     GWEN_IO_LAYER *io,
-			     GWEN_DB_NODE *params,
-			     uint32_t guiid);
+			     GWEN_SYNCIO *sio,
+			     GWEN_DB_NODE *params);
 
 static
-int AH_ImExporterSEPA_CheckFile(AB_IMEXPORTER *ie, const char *fname, uint32_t guiid);
+int AH_ImExporterSEPA_CheckFile(AB_IMEXPORTER *ie, const char *fname);
 
 
 static
 int AH_ImExporterSEPA_Export_Ccm(AB_IMEXPORTER *ie,
 				 AB_IMEXPORTER_CONTEXT *ctx,
-				 GWEN_IO_LAYER *io,
-				 GWEN_DB_NODE *params,
-				 uint32_t guiid);
+				 GWEN_SYNCIO *sio,
+				 GWEN_DB_NODE *params);
 
 
 #endif /* AQHBCI_IMEX_SEPA_P_H */
