@@ -88,7 +88,7 @@ int AHB_SWIFT940_Parse_25(const AHB_SWIFT_TAG *tg,
     while(*p2 && isdigit(*p2))
       p2++;
     if (p2==p) {
-      DBG_WARN(AQBANKING_LOGDOMAIN,
+      DBG_INFO(AQBANKING_LOGDOMAIN,
                "LocalAccountNumber starts with nondigits (%s)", p);
       AHB_SWIFT__SetCharValue(data,
                               GWEN_DB_FLAGS_OVERWRITE_VARS,
@@ -554,7 +554,7 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
   int d1b, d2b, d3b;
   int neg;
   GWEN_TIME *ti;
-  char curr3=0;
+  //char curr3=0;
   const char *currency;
 
   p=AHB_SWIFT_Tag_GetData(tg);
@@ -615,11 +615,11 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
      * is and the valuta month differ by more than 10 months then the year
      * of the booking date will be adjusted.
      */
-    if (d2b-d2a>10) {
+    if (d2b-d2a>7) {
       /* booked before actually withdrawn */
       d1b=d1a-1;
     }
-    else if (d2a-d2b>10) {
+    else if (d2a-d2b>7) {
       /* withdrawn and booked later */
       d1b=d1a+1;
     }
@@ -667,7 +667,7 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
   }
   if (!isdigit(*p)) {
     /* found third character, skip it */
-    curr3=*p;
+    //curr3=*p;
     p++;
     bleft--;
   }
